Class: Notiflows::Models::NotiflowRunResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/notiflows/models/notiflow_run_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(notiflow_run_id:) ⇒ Object

Response after successfully running a notiflow

Parameters:

  • notiflow_run_id (String) —

    ID of the notiflow run. Use this to query notifications created by this run.



# File 'lib/notiflows/models/notiflow_run_response.rb', line 13

Instance Attribute Details

#notiflow_run_id ⇒ String

ID of the notiflow run. Use this to query notifications created by this run.

Returns:

  • (String)


11
# File 'lib/notiflows/models/notiflow_run_response.rb', line 11

required :notiflow_run_id, String